local E, L, V, P, G = unpack(ElvUI)
local MyPluginName = "ThinkTankUI"
local ThinkTankUI = E:NewModule(MyPluginName, 'AceHook-3.0', 'AceEvent-3.0', 'AceTimer-3.0', "AceConsole-3.0");

local LSM = LibStub('LibSharedMedia-3.0')
local EP = LibStub('LibElvUIPlugin-1.0')
local addon, ns = ...

local _G = _G
local pairs, print = pairs, print
local format = string.format
local CreateFrame = CreateFrame
local C_TimerAfter = C_Timer.After


ThinkTankUI.Config = {}
ThinkTankUI["styles"] = {}
ThinkTankUI["softGlow"] = {}
ThinkTankUI.TexCoords = {.08, 0.92, -.04, 0.92}
ThinkTankUI.Title = format('|cff00c0fa%s |r', 'ThinkTankUI')
ThinkTankUI.Version = GetAddOnMetadata('ElvUI_ThinkTankUI_RM', 'Version')
ThinkTankUI.NewSign = '|TInterface\\OptionsFrame\\UI-OptionsFrame-NewFeatureIcon:14:14|t'
BINDING_HEADER_ThinkTankUI = ThinkTankUI.Title

function ThinkTankUI:IsAddOnEnabled(addon) -- Credit: Azilroka
	return GetAddOnEnableState(E.myname, addon) == 2
end

local classColor = E.myclass == 'PRIEST' and E.PriestColors or (CUSTOM_CLASS_COLORS and CUSTOM_CLASS_COLORS[E.myclass] or RAID_CLASS_COLORS[E.myclass])

function ThinkTankUI:cOption(name)
	local color = '|cff00c0fa%s |r'
	return (color):format(name)
end

function ThinkTankUI:PrintURL(url) -- Credit: Azilroka
	return format("|cFF00c0fa[|Hurl:%s|h%s|h]|r", url, url)
end

function ThinkTankUI:AddOptions()
	for _, func in pairs(ThinkTankUI.Config) do
		func()
	end
end

function ThinkTankUI:LoadOptions()
	E:ToggleOptionsUI(); LibStub("AceConfigDialog-3.0-ElvUI"):SelectGroup("ElvUI", "ThinkTankUI")
end

function ThinkTankUI:LoadCommands()
	self:RegisterChatCommand("ThinkTankUI", "LoadOptions")
end



function ThinkTankUI:Initialize()
	self:LoadCommands()
	
	-- run install when ElvUI install finishes
   E["global"][MyPluginName] = E["global"][MyPluginName] or {}
	
	local _, _ , major, minor = string.find(ThinkTankUI.Version, "(%d+).(%d+)")
	local majorUser, minorUser
	if E.db[MyPluginName].install_version ~= nil then
		_, _ ,majorUser, minorUser = string.find(E.db[MyPluginName].install_version, "(%d+).(%d+)")
	end
	if E.private.install_complete and (E.db[MyPluginName].install_version == nil or (majorUser ~= major or minorUser ~= minor)) then
		E:GetModule("PluginInstaller"):Queue(ThinkTankUI.ThinkTankUIInstallTable)
	end
	
	if E.db.ThinkTankUI.general.loginMessage then
		print(ThinkTankUI.Title..format('v|cff00c0fa%s|r',ThinkTankUI.Version)..L[' is loaded. For any issues or suggestions, please visit ']..ThinkTankUI:PrintURL('https://git.tukui.org/MaximumOverdrive/ThinkTankUI-Remastered/issues'))
	end
	EP:RegisterPlugin(addon, self.AddOptions)

end

local function InitializeCallback()
	ThinkTankUI:Initialize()
end

E:RegisterModule(MyPluginName, InitializeCallback)